[前][次][番号順一覧][スレッド一覧]

ruby-changes:11245

From: nobu <ko1@a...>
Date: Mon, 9 Mar 2009 16:49:30 +0900 (JST)
Subject: [ruby-changes:11245] Ruby:r22854 (trunk): * lib/rake: updated to rake code to rake-0.8.4 source code base.

nobu	2009-03-09 16:49:14 +0900 (Mon, 09 Mar 2009)

  New Revision: 22854

  http://svn.ruby-lang.org/cgi-bin/viewvc.cgi?view=rev&revision=22854

  Log:
    * lib/rake: updated to rake code to rake-0.8.4 source code base.

  Modified files:
    trunk/ChangeLog
    trunk/lib/rake/packagetask.rb
    trunk/lib/rake/rdoctask.rb
    trunk/lib/rake.rb

Index: ChangeLog
===================================================================
--- ChangeLog	(revision 22853)
+++ ChangeLog	(revision 22854)
@@ -1,3 +1,7 @@
+Mon Mar  9 16:49:13 2009  Nobuyoshi Nakada  <nobu@r...>
+
+	* lib/rake: updated to rake code to rake-0.8.4 source code base.
+
 Mon Mar  9 16:03:37 2009  Nobuyoshi Nakada  <nobu@r...>
 
 	* lib/rubygems/installer.rb (Gem::Installer#initialize): env may
Index: lib/rake/packagetask.rb
===================================================================
--- lib/rake/packagetask.rb	(revision 22853)
+++ lib/rake/packagetask.rb	(revision 22854)
@@ -42,7 +42,7 @@
   #   end
   #
   class PackageTask < TaskLib
-    # Name of the package.
+    # Name of the package (from the GEM Spec).
     attr_accessor :name
 
     # Version of the package (e.g. '1.3.2').
@@ -120,7 +120,6 @@
           task :package => ["#{package_dir}/#{file}"]
           file "#{package_dir}/#{file}" => [package_dir_path] + package_files do
             chdir(package_dir) do
-              sh %{env}
               sh %{#{@tar_command} #{flag}cvf #{file} #{package_name}}
             end
           end
Index: lib/rake.rb
===================================================================
--- lib/rake.rb	(revision 22853)
+++ lib/rake.rb	(revision 22854)
@@ -1,6 +1,6 @@
 #--
 
-# Copyright (c) 2003, 2004, 2005, 2006, 2007  Jim Weirich
+# Copyright 2003, 2004, 2005, 2006, 2007, 2008 by Jim Weirich (jim@w...)
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to
@@ -27,7 +27,7 @@
 # as a library via a require statement, but it can be distributed
 # independently as an application.
 
-RAKEVERSION = '0.8.3'
+RAKEVERSION = '0.8.4'
 
 require 'rbconfig'
 require 'fileutils'
@@ -72,7 +72,7 @@
 #
 class String
   rake_extension("ext") do
-    # Replace the file extension with +newext+.  If there is no extenson on
+    # Replace the file extension with +newext+.  If there is no extension on
     # the string, append the new extension to the end.  If the new extension
     # is not given, or is the empty string, remove any existing extension.
     #
@@ -743,9 +743,7 @@
     # Is this file task needed?  Yes if it doesn't exist, or if its time stamp
     # is out of date.
     def needed?
-      return true unless File.exist?(name)
-      return true if out_of_date?(timestamp)
-      false
+      ! File.exist?(name) || out_of_date?(timestamp)
     end
 
     # Time stamp for file task.
@@ -967,7 +965,7 @@
       }
     end
     if RakeFileUtils.verbose_flag == :default
-      options[:verbose] = false
+      options[:verbose] = true
     else
       options[:verbose] ||= RakeFileUtils.verbose_flag
     end
@@ -1230,23 +1228,21 @@
     # Now do the delegation.
     DELEGATING_METHODS.each_with_index do |sym, i|
       if SPECIAL_RETURN.include?(sym)
-        ln = __LINE__+1
-        class_eval %{
+        class_eval <<-END, __FILE__, __LINE__+1
           def #{sym}(*args, &block)
             resolve
             result = @items.send(:#{sym}, *args, &block)
             FileList.new.import(result)
           end
-        }, __FILE__, ln
+        END
       else
-        ln = __LINE__+1
-        class_eval %{
+        class_eval <<-END, __FILE__, __LINE__+1
           def #{sym}(*args, &block)
             resolve
             result = @items.send(:#{sym}, *args, &block)
             result.object_id == @items.object_id ? self : result
           end
-        }, __FILE__, ln
+        END
       end
     end
 
@@ -1454,8 +1450,8 @@
       collect { |fn| fn.pathmap(spec) }
     end
 
-    # Return a new array with <tt>String#ext</tt> method applied to each
-    # member of the array.
+    # Return a new file list with <tt>String#ext</tt> method applied
+    # to each member of the array.
     #
     # This method is a shortcut for:
     #
@@ -1641,9 +1637,9 @@
       @task_manager.lookup(name, @scope)
     end
 
-    # Return the list of tasks defined in this namespace.
+    # Return the list of tasks defined in this and nested namespaces.
     def tasks
-      @task_manager.tasks
+      @task_manager.tasks_in_scope(@scope)
     end
   end # NameSpace
 
@@ -1788,6 +1784,15 @@
       @tasks.values.sort_by { |t| t.name }
     end
 
+    # List of all the tasks defined in the given scope (and its
+    # sub-scopes).
+    def tasks_in_scope(scope)
+      prefix = scope.join(":")
+      tasks.select { |t|
+        /^#{prefix}:/ =~ t.name
+      }
+    end
+
     # Clear all tasks in this application.
     def clear
       @tasks.clear
@@ -1966,7 +1971,8 @@
     def init(app_name='rake')
       standard_exception_handling do
         @name = app_name
-        collect_tasks handle_options
+        handle_options
+        collect_tasks
       end
     end
 
@@ -2033,7 +2039,7 @@
         exit(false)
       rescue Exception => ex
         # Exit with error message
-        $stderr.puts "rake aborted!"
+        $stderr.puts "#{name} aborted!"
         $stderr.puts ex.message
         if options.trace
           $stderr.puts ex.backtrace.join("\n")
@@ -2049,7 +2055,10 @@
     # If a match is found, it is copied into @rakefile.
     def have_rakefile
       @rakefiles.each do |fn|
-        if File.exist?(fn) || fn == ''
+        if File.exist?(fn)
+          others = Dir.glob(fn, File::FNM_CASEFOLD)
+          return others.size == 1 ? others.first : fn
+        elsif fn == ''
           return fn
         end
       end
@@ -2072,14 +2081,14 @@
       tty_output? || ENV['RAKE_COLUMNS']
     end
 
-    # Display the tasks and dependencies.
+    # Display the tasks and comments.
     def display_tasks_and_comments
       displayable_tasks = tasks.select { |t|
         t.comment && t.name =~ options.show_task_pattern
       }
       if options.full_description
         displayable_tasks.each do |t|
-          puts "rake #{t.name_with_args}"
+          puts "#{name} #{t.name_with_args}"
           t.full_comment.split("\n").each do |line|
             puts "    #{line}"
           end
@@ -2138,7 +2147,7 @@
     # Display the tasks and prerequisites
     def display_prerequisites
       tasks.each do |t|
-        puts "rake #{t.name}"
+        puts "#{name} #{t.name}"
         t.prerequisites.each { |pre| puts "    #{pre}" }
       end
     end
@@ -2250,7 +2259,7 @@
             verbose(true)
           }
         ],
-        ['--verbose', '-v', "Log message to standard output (default).",
+        ['--verbose', '-v', "Log message to standard output.",
           lambda { |value| verbose(true) }
         ],
         ['--version', '-V', "Display the program version.",
@@ -2266,18 +2275,18 @@
     def handle_options
       options.rakelib = ['rakelib']
 
-      opts = OptionParser.new
-      opts.banner = "rake [-f rakefile] {options} targets..."
-      opts.separator ""
-      opts.separator "Options are ..."
+      OptionParser.new do |opts|
+        opts.banner = "rake [-f rakefile] {options} targets..."
+        opts.separator ""
+        opts.separator "Options are ..."
 
-      opts.on_tail("-h", "--help", "-H", "Display this help message.") do
-        puts opts
-        exit
-      end
+        opts.on_tail("-h", "--help", "-H", "Display this help message.") do
+          puts opts
+          exit
+        end
 
-      standard_rake_options.each { |args| opts.on(*args) }
-      parsed_argv = opts.parse(ARGV)
+        standard_rake_options.each { |args| opts.on(*args) }
+      end.parse!
 
       # If class namespaces are requested, set the global options
       # according to the values in the options structure.
@@ -2288,7 +2297,6 @@
         $dryrun = options.dryrun
         $silent = options.silent
       end
-      parsed_argv
     end
 
     # Similar to the regular Ruby +require+ command, but will check
@@ -2379,9 +2387,9 @@
     # Collect the list of tasks on the command line.  If no tasks are
     # given, return a list containing only the default task.
     # Environmental assignments are processed at this time as well.
-    def collect_tasks(argv)
+    def collect_tasks
       @top_level_tasks = []
-      argv.each do |arg|
+      ARGV.each do |arg|
         if arg =~ /^(\w+)=(.*)$/
           ENV[$1] = $2
         else

Index: lib/rake/rdoctask.rb
===================================================================
--- lib/rake/rdoctask.rb	(revision 22853)
+++ lib/rake/rdoctask.rb	(revision 22854)
@@ -8,7 +8,7 @@
   #
   # The RDocTask will create the following targets:
   #
-  # [<b><em>rdoc</em></b>]
+  # [<b>:<em>rdoc</em></b>]
   #   Main task for this RDOC task.
   #
   # [<b>:clobber_<em>rdoc</em></b>]
@@ -19,13 +19,18 @@
   #   Rebuild the rdoc files from scratch, even if they are not out
   #   of date.
   #
-  # Simple Example:
+  # Simple example:
   #
   #   Rake::RDocTask.new do |rd|
   #     rd.main = "README.rdoc"
   #     rd.rdoc_files.include("README.rdoc", "lib/**/*.rb")
   #   end
   #
+  # The +rd+ object passed to the block is an RDocTask object. See the
+  # attributes list for the RDocTask class for available customization options.
+  #
+  # == Specifying different task names
+  #
   # You may wish to give the task a different name, such as if you are
   # generating two sets of documentation.  For instance, if you want to have a
   # development set of documentation including private methods:
@@ -39,6 +44,16 @@
   # The tasks would then be named :<em>rdoc_dev</em>, :clobber_<em>rdoc_dev</em>, and
   # :re<em>rdoc_dev</em>.
   #
+  # If you wish to have completely different task names, then pass a Hash as
+  # first argument. With the <tt>:rdoc</tt>, <tt>:clobber_rdoc</tt> and
+  # <tt>:rerdoc</tt> options, you can customize the task names to your liking.
+  # For example:
+  #
+  #   Rake::RDocTask.new(:rdoc => "rdoc", :clobber_rdoc => "rdoc:clean", :rerdoc => "rdoc:force")
+  #
+  # This will create the tasks <tt>:rdoc</tt>, <tt>:rdoc_clean</tt> and
+  # <tt>:rdoc:force</tt>.
+  #
   class RDocTask < TaskLib
     # Name of the main, top level task.  (default is :rdoc)
     attr_accessor :name
@@ -46,7 +61,7 @@
     # Name of directory to receive the html output files. (default is "html")
     attr_accessor :rdoc_dir
 
-    # Title of RDoc documentation. (default is none)
+    # Title of RDoc documentation. (defaults to rdoc's default)
     attr_accessor :title
 
     # Name of file to be used as the main, top level file of the
@@ -59,14 +74,24 @@
     # List of files to be included in the rdoc generation. (default is [])
     attr_accessor :rdoc_files
 
-    # List of options to be passed rdoc.  (default is [])
+    # Additional list of options to be passed rdoc.  (default is [])
     attr_accessor :options
 
-    # Run the rdoc process as an external shell (default is false)
+    # Whether to run the rdoc process as an external shell (default is false)
     attr_accessor :external
 
-    # Create an RDoc task named <em>rdoc</em>.  Default task name is +rdoc+.
-    def initialize(name=:rdoc)  # :yield: self
+    attr_accessor :inline_source
+
+    # Create an RDoc task with the given name. See the RDocTask class overview
+    # for documentation.
+    def initialize(name = :rdoc)  # :yield: self
+      if name.is_a?(Hash)
+        invalid_options = name.keys.map { |k| k.to_sym } - [:rdoc, :clobber_rdoc, :rerdoc]
+        if !invalid_options.empty?
+          raise ArgumentError, "Invalid option(s) passed to RDocTask.new: #{invalid_options.join(", ")}"
+        end
+      end
+
       @name = name
       @rdoc_files = Rake::FileList.new
       @rdoc_dir = 'html'
@@ -74,6 +99,7 @@
       @title = nil
       @template = nil
       @external = false
+      @inline_source = true
       @options = []
       yield self if block_given?
       define
@@ -81,27 +107,28 @@
 
     # Create the tasks defined by this task lib.
     def define
-      if name.to_s != "rdoc"
+      if rdoc_task_name != "rdoc"
         desc "Build the RDOC HTML Files"
+      else
+        desc "Build the #{rdoc_task_name} HTML Files"
       end
+      task rdoc_task_name
 
-      desc "Build the #{name} HTML Files"
-      task name
-
       desc "Force a rebuild of the RDOC files"
-      task "re#{name}" => ["clobber_#{name}", name]
+      task rerdoc_task_name => [clobber_task_name, rdoc_task_name]
 
       desc "Remove rdoc products"
-      task "clobber_#{name}" do
+      task clobber_task_name do
         rm_r rdoc_dir rescue nil
       end
 
-      task :clobber => ["clobber_#{name}"]
+      task :clobber => [clobber_task_name]
 
       directory @rdoc_dir
-      task name => [rdoc_target]
+      task rdoc_task_name => [rdoc_target]
       file rdoc_target => @rdoc_files + [Rake.application.rakefile] do
         rm_r @rdoc_dir rescue nil
+        @before_running_rdoc.call if @before_running_rdoc
         args = option_list + @rdoc_files
         if @external
           argstring = args.join(' ')
@@ -120,6 +147,7 @@
       result << "--main" << quote(main) if main
       result << "--title" << quote(title) if title
       result << "-T" << quote(template) if template
+      result << "--inline-source" if inline_source && !@options.include?("--inline-source") && !@options.include?("-S")
       result
     end
 
@@ -135,11 +163,45 @@
       option_list.join(' ')
     end
 
+    # The block passed to this method will be called just before running the
+    # RDoc generator. It is allowed to modify RDocTask attributes inside the
+    # block.
+    def before_running_rdoc(&block)
+      @before_running_rdoc = block
+    end
+
     private
 
     def rdoc_target
       "#{rdoc_dir}/index.html"
     end
 
+    def rdoc_task_name
+      case name
+      when Hash
+        (name[:rdoc] || "rdoc").to_s
+      else
+        name.to_s
+      end
+    end
+
+    def clobber_task_name
+      case name
+      when Hash
+        (name[:clobber_rdoc] || "clobber_rdoc").to_s
+      else
+        "clobber_#{name}"
+      end
+    end
+
+    def rerdoc_task_name
+      case name
+      when Hash
+        (name[:rerdoc] || "rerdoc").to_s
+      else
+        "re#{name}"
+      end
+    end
+
   end
 end
--
ML: ruby-changes@q...
Info: http://www.atdot.net/~ko1/quickml/

[前][次][番号順一覧][スレッド一覧]